/****************************************************  Hardware Defaults  ******************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures that configure hardware settings.

	Rev History:  08-04-2016:	Added Model 370 support.
				  02-18-2016:	Added Model 372 and Model 373 support.
				  08-06-2015:	Changed the phase setting for DCLK in the Model 376 ADC configuration.
				  07-14-2015:	Corrected CTRL pin setting at address 0x20 of every ADS42LB69 chip.
				  12-08-2014:	Added Model 371 support.
				  07-21-2014:	Added Model 377 support and restructured default setting files.
				  01-10-2014:	Inital release.

	Copyright 2014, Red Rapids, Inc.

*****************************************************  Hardware Defaults  *****************************************************/
#include <string.h>

#include "adapter.h"
#include "sigfpga.h"
#include "dma_functions.h"
#include "common_functions.h"
#include "channel_functions.h"
#include "device_functions.h"
#include "product_functions.h"

#if defined(__cplusplus)
	extern "C" {
#endif

//////////////////////////////////////////  Configure GPIO and USER Signal Direction  //////////////////////////////////////////

// Initialize a default structure for the GPIO and USER (#51 - #62) connector pin direction settings.
s_PinDirection PinDirectionDefault = {
	{ // GPIO Direction
		0,	// GPIO #1		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// GPIO #2		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// GPIO #3		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// GPIO #4		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// GPIO #5		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0	// GPIO #6		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
	},
	{ // USER Direction
		0,	// USER #1		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #2		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #3		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #4		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #5		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #6		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #7		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #8		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #9		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #10		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #11		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #12		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #13		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #14		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #15		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #16		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #17		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #18		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #19		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #20		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #21		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #22		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #23		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #24		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #25		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #26		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #27		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #28		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #29		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #30		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #31		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #32		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #33		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #34		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #35		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #36		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #37		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #38		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #39		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #40		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #41		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #42		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #43		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #44		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #45		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #46		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #47		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #48		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #49		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #50		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #51		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #52		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #53		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #54		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #55		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #56		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #57		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #58		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #59		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #60		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0,	// USER #61		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
		0	// USER #62		Set the signal direction to input or output. - Range: 0 (input) to 1 (output)
	},
};

////////////////////////////////////////////////  Configure Model 370 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 376 device initialization.
s_M370Devices M370Default = {
	{	// RX1_ADC - REFER TO THE ADC12D1600 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes all addresses in sequence.
		{
		// {4-bit Address, 16-bit Data}
		{0x0,0x2090},	// Configuration Register 1  (DDR 90 Phase, High Voltage, Two's Complement)
		{0x2,0x0000},	// I-channel Offset Adjust  (Device Default)
		{0x3,0x4000},	// I-channel Full-Scale Range Adjust  (Device Default)
		{0x4,0xDF4B},	// Calibration Adjust  (Device Default)
		{0x5,0x0000},	// Calibration Values  (Read Only - Data Not Used)
		{0x7,0x8140},	// DES Timing Adjust  (Device Default)
		{0xA,0x0000},	// Q-channel Offset Adjust  (Device Default)
		{0xB,0x4000},	// Q-channel Full-Scale Range Adjust  (Device Default)
		{0xC,0x0004},	// Aperture Delay Coarse Adjust  (Device Default)
		{0xD,0x0000},	// Aperture Delay Fine Adjust  (Device Default)
		{0xE,0x0003}	// AutoSync  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{4,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{3,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	}
};

////////////////////////////////////////////////  Configure Model 371 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 371 device initialization.
s_M371Devices M371Default = {
	{  // AD9512 - REFER TO THE AD9512 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x0000,0x10},	// Serial Control Port Configuration
		{0x0034,0x01},	// Delay Bypass 4  (Device Default)
		{0x0035,0x00},	// Delay Full-Scale 4  (Device Default)
		{0x0036,0x00},	// Delay Fine Adjust 4  (Device Default)
		{0x003D,0x08},	// LVPECL OUT0  (Device Default)
		{0x003E,0x08},	// LVPECL OUT1  (Device Default)
		{0x003F,0x08},	// LVPECL OUT2  (Device Default)
		{0x0040,0x01},	// LVDS_CMOS OUT3  (Power Down OUT3)
		{0x0041,0x02},	// LVDS_CMOS OUT4  (Device Default)
		{0x0045,0x05},	// Clocks Select, Power-Down Options (Select Internal Sample Clock Source)
		{0x004A,0x00},	// Divider 0  (Device Default)
		{0x004B,0x80},	// Divider 0  (Bypass DIV0)
		{0x004C,0x11},	// Divider 1  (Device Default)
		{0x004D,0x80},	// Divider 1  (Bypass DIV1)
		{0x004E,0x33},	// Divider 2  (Device Default)
		{0x004F,0x80},	// Divider 2  (Bypass DIV2)
		{0x0050,0x00},	// Divider 3  (Device Default)
		{0x0051,0x00},	// Divider 3  (Device Default)
		{0x0052,0x11},	// Divider 4  (Device Default)
		{0x0053,0x80},	// Divider 4  (Bypass DIV4)
		{0x0058,0x00},	// Function Pin and Sync  (Device Default)
		{0x005A,0x01}	// Update Registers  (Update Registers)
		}
	},
	{  // ADS42LB69 - REFER TO THE ADS42LB69 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x04,0x00},	// LVDS Configuration #1  (Device Default)
		{0x05,0x00},	// LVDS Configuration #2  (Device Default)
		{0x06,0x00},	// Clock Divider  (Device Default)
		{0x07,0x00},	// SYNC Delay  (Device Default)
		{0x08,0x08},	// Power and Data Format Configuration  (Disable CTRL Pins)
		{0x0B,0x00},	// Channel A Gain Setting and Bit Ordering  (Device Default)
		{0x0C,0x00},	// Channel B Gain Setting and Bit Ordering  (Device Default)
		{0x0D,0x00},	// Over-range Setting  (Device Default)
		{0x0F,0x00},	// Test Pattern Selection  (Device Default)
		{0x10,0x00},	// Custom Pattern #1 (15:8) (Device Default)
		{0x11,0x00},	// Custom Pattern #1 (7:0)  (Device Default)
		{0x12,0x00},	// Custom Pattern #2 (15:8)  (Device Default)
		{0x13,0x00},	// Custom Pattern #2 (7:0)  (Device Default)
		{0x14,0x00},	// Output Drive Strength  (Device Default)
		{0x15,0x01},	// Output Driver Format  (Set DDR LVDS Mode)
		{0x16,0x00},	// Output Driver Timing  (Device Default)
		{0x17,0x00},	// Channel A Output Clock Timing  (Device Default)
		{0x18,0x00},	// Channel B Output Clock Timing  (Device Default)
		{0x1F,0xFF},	// Fast Over-range Threshold  (Device Default)
		{0x20,0x01},	// CTLR Pin Mode Select  (OVR)
		{0x30,0x00}		// SYNC Enable  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1TO2_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{7,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{6,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	},
	{  // ADF4110 - Sample Clock Frequency (Fout) = 100,000*[(16*B) + A] where A < 16.
	   // Example (A=0, B=100):  Fout = 100,000*[(16*100) + 0] = 160 MHz
		0,	// A		A counter. - Range: 6 bits
		100	// B		B counter. - Range: 13 bits
	}
};

////////////////////////////////////////////////  Configure Model 372 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 372 device initialization.
s_M372Devices M372Default = {
	{  // LMK01000 - REFER TO THE LMK01000 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x0,0x0001010},	// CLKout0 Output Control  (Enabled)
		{0x1,0x0000010},	// CLKout1 Output Control  (Device Default)
		{0x2,0x0000010},	// CLKout2 Output Control  (Device Default)
		{0x3,0x0001010},	// CLKout3 Output Control  (Device Default)
		{0x4,0x0001010},	// CLKout4 Output Control  (Enabled)
		{0x5,0x0001010},	// CLKout5 Output Control  (Enabled)
		{0x6,0x0000010},	// CLKout6 Output Control  (Device Default)
		{0x7,0x0000010},	// CLKout7 Output Control  (Device Default)
		{0x9,0x00022A0},	// Voltage Boost Bit (Device Default)
		{0xE,0x6800000}		// Global Settings  (Select CLKin0)
		}
	},
	{  // AD9652 - REFER TO THE AD9652 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data (read only registers not included).
		{
		{0x000,0x18},	// SPI Port Configuraion (global)  (Device Default)
		{0x005,0x03},	// Channel Index (global)  (Device Default)
		{0x008,0x80},	// Power Modes SHADOW REGISTER (local)  (Device Default)
		{0x009,0x01},	// Global Clock SHADOW REGISTER (global)  (Device Default)
		{0x00B,0x00},	// Clock Divide SHADOW REGISTER (global)  (Device Default)
		{0x00D,0x00},	// Test Mode SHADOW REGISTER (local)  (Device Default)
		{0x00F,0x00},	// Common-mode Servo SHADOW REGISTER (global)  (Device Default)
		{0x010,0x00},	// Offset Adjust SHADOW REGISTER (local) (Device Default)
		{0x014,0x01},	// Output Mode SHADOW REGISTER (local)  (Twos Complement)
		{0x015,0x00},	// Output LVDS Control (global)  (Device Default)
		{0x016,0x00},	// Clock Phase Adjust SHADOW REGISTER (global)  (Device Default)
		{0x017,0x00},	// DCO Output Delay SHADOW REGISTER (global)  (Device Default)
		{0x018,0xC0},	// Input Span Select (global)  (Device Default)
		{0x030,0x00},	// Dither SHADOW REGISTER (local)  (Device Default)
		{0x045,0x00},	// Fast Detect (FD) Control  (Device Default)
		{0x047,0x08},	// FD Upper Threshold  (Device Default)
		{0x049,0x00},	// FD Lower Threshold [7:0]  (Device Default)
		{0x04A,0x02},	// FD Lower Threshold [14:8] (Device Default)
		{0x04B,0x00},	// FD Dwell Time [7:0]  (Device Default)
		{0x04C,0x08},	// FD Dwell Time [15:8]  (Device Default)
		{0x0FF,0x01},	// Transfer (global)  (Transfer SHADOW REGISTER Contents)
		{0x100,0x00},	// Sync Control (global)  (Device Default)
		{0x212,0x00},	// Dither Gain (global)  (Device Default)
		{0x22A,0x00},	// Input Frequency Settings (global)  (Device Default)
		{0x4FA,0x03},	// Calibration Power-down Configuration (global)  (Device Default)
		{0x4FB,0x08}	// Calibration Power-down Configuration (global)  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1_AMP_ENBL - REFER TO THE ADA4927 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{7,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{	// RX2_AMP_ENBL - REFER TO THE ADA4927 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{6,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{  // AD9142A - REFER TO THE AD9142A DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data (read only registers not included).
		{
		{0x00,0x00},	// Common  (Device Default)
		{0x01,0xC0},	// Power Down Control  (Device Default)
		{0x03,0x00},	// Interrupt Enable 0  (Device Default)
		{0x04,0x00},	// Interrupt Enable 1  (Device Default)
		{0x07,0x00},	// IRQ Select 0  (Device Default)
		{0x08,0x00},	// IRQ Select 1 (local)  (Device Default)
		{0x09,0x00},	// Frame Mode  (Device Default)
		{0x0A,0xC0},	// Data Control 0  (DLL Enabled)
		{0x0B,0x39},	// Data Control 1  (Device Default)
		{0x0D,0x06},	// Data Control 3  (Device Default)
		{0x10,0xFF},	// DACCLK Receiver Control (Device Default)
		{0x11,0x5F},	// REFCLK Receiver Control (Device Default)
		{0x12,0x00},	// PLL Control 0  (Device Default)
		{0x14,0xE7},	// PLL Control 2  (Device Default)
		{0x15,0xC4},	// PLL Control 3  (Loop Divider = 2, VCO Divider = 2)
		{0x18,0xF9},	// IDAC Full Scale Adjust 0  (Device Default)
		{0x19,0xE1},	// IDAC Full Scale Adjust 1  (Device Default)
		{0x1A,0xF9},	// QDAC Full Scale Adjust 0  (Device Default)
		{0x1B,0x01},	// QDAC Full Scale Adjust 1  (Device Default)
		{0x1C,0x02},	// Die Temperature Sensor Control  (Device Default)
		{0x20,0x00},	// Interrupt Configuration  (Device Default)
		{0x21,0x00},	// SYNC Control  (Device Default)
		{0x22,0x12},	// Frame Reset Control  (Device Default)
		{0x23,0x40},	// FIFO Level Configuration  (Device Default)
		{0x25,0x00},	// FIFO Control  (Device Default)
		{0x26,0x00},	// Data Format  (Device Default)
		{0x27,0x00},	// Datapath Control  (Device Default)
		{0x28,0x00},	// Interpolation Control  (Device Default)
		{0x29,0x00},	// Over Threshold Control 0  (Device Default)
		{0x2A,0x00},	// Over Threshold Control 1  (Device Default)
		{0x2B,0x00},	// Over Threshold Control 2  (Device Default)
		{0x30,0x00},	// NCO Control  (Device Default)
		{0x31,0x00},	// NCO Frequency Tuning Word 0  (Device Default)
		{0x32,0x00},	// NCO Frequency Tuning Word 1  (Device Default)
		{0x33,0x00},	// NCO Frequency Tuning Word 2  (Device Default)
		{0x34,0x10},	// NCO Frequency Tuning Word 3  (Device Default)
		{0x35,0x00},	// NCO Phase Offset 0  (Device Default)
		{0x36,0x00},	// NCO Phase Offset 1  (Device Default)
		{0x37,0x00},	// IQ Phase Adjust 0  (Device Default)
		{0x38,0x00},	// IQ Phase Adjust 1  (Device Default)
		{0x39,0x00},	// LVDS Input Power Down 0  (Device Default)
		{0x3B,0x00},	// IDAC DC Offset 0  (Device Default)
		{0x3C,0x00},	// IDAC DC Offset 1  (Device Default)
		{0x3D,0x00},	// QDAC DC Offset 0  (Device Default)
		{0x3E,0x00},	// QDAC DC Offset 1  (Device Default)
		{0x3F,0x20},	// IDAC Gain Adjust  (Device Default)
		{0x40,0x20},	// QDAC Gain Adjust  (Device Default)
		{0x41,0x01},	// Gain Step Control 0  (Device Default)
		{0x42,0x41},	// Gain Step Control 1  (Device Default)
		{0x43,0x07},	// TX Enable Control  (Device Default)
		{0x44,0x00},	// DAC Output Control  (Disabel Output Control)
		{0x5E,0xFE},	// Enable DLL Delay Cell 0  (Turn Off LSB Delay Cell)
		{0x5F,0x67},	// Enable DLL Delay Cell 1  (Device Default)
		{0x60,0x00},	// Sample Error Detection Control  (Device Default)
		{0x61,0x00},	// Sample Error Detection Pattern LSB I0  (Device Default)
		{0x62,0x00},	// Sample Error Detection Pattern MSB I0  (Device Default)
		{0x63,0x00},	// Sample Error Detection Pattern LSB Q0  (Device Default)
		{0x64,0x00},	// Sample Error Detection Pattern MSB Q0  (Device Default)
		{0x65,0x00},	// Sample Error Detection Pattern LSB I1  (Device Default)
		{0x66,0x00},	// Sample Error Detection Pattern MSB I1  (Device Default)
		{0x67,0x00},	// Sample Error Detection Pattern LSB Q1  (Device Default)
		{0x68,0x00},	// Sample Error Detection Pattern MSB Q1  (Device Default)
		{0x6A,0x00}	// Parity Control  (Device Default)
		}
	},
	{	// TX3_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// TX4_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// TX3_AMP_ENBL - REFER TO THE AD8000 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{5,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{	// TX4_AMP_ENBL - REFER TO THE AD8000 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{4,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{  // PROG_SYNTH - Refer to product documentation for a detail description.
		// Note: Programmable synthesizer is a build option.
		0,	// Output Frequency
		{
		// Reserved
		{0x0,0x00},		// Reserved
		{0x1,0x00},		// Reserved
		{0x2,0x00},		// Reserved
		{0x3,0x00},		// Reserved
		{0x4,0x00},		// Reserved
		{0x5,0x00},		// Reserved
		{0x6,0x00},		// Reserved
		{0x7,0x00}		// Reserved
		}
	}
};

////////////////////////////////////////////////  Configure Model 373 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 373 device initialization.
s_M373Devices M373Default = {
	{  // LMK01000 - REFER TO THE LMK01000 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x0,0x0001010},	// CLKout0 Output Control  (Enabled)
		{0x1,0x0000010},	// CLKout1 Output Control  (Device Default)
		{0x2,0x0000010},	// CLKout2 Output Control  (Device Default)
		{0x3,0x0001010},	// CLKout3 Output Control  (Device Default)
		{0x4,0x0001010},	// CLKout4 Output Control  (Enabled)
		{0x5,0x0001010},	// CLKout5 Output Control  (Enabled)
		{0x6,0x0000010},	// CLKout6 Output Control  (Device Default)
		{0x7,0x0000010},	// CLKout7 Output Control  (Device Default)
		{0x9,0x00022A0},	// Voltage Boost Bit (Device Default)
		{0xE,0x6800000}		// Global Settings  (Select CLKin0)
		}
	},
	{  // AD9652 - REFER TO THE AD9652 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data (read only registers not included).
		{
		{0x000,0x18},	// SPI Port Configuraion (global)  (Device Default)
		{0x005,0x03},	// Channel Index (global)  (Device Default)
		{0x008,0x80},	// Power Modes SHADOW REGISTER (local)  (Device Default)
		{0x009,0x01},	// Global Clock SHADOW REGISTER (global)  (Device Default)
		{0x00B,0x00},	// Clock Divide SHADOW REGISTER (global)  (Device Default)
		{0x00D,0x00},	// Test Mode SHADOW REGISTER (local)  (Device Default)
		{0x00F,0x00},	// Common-mode Servo SHADOW REGISTER (global)  (Device Default)
		{0x010,0x00},	// Offset Adjust SHADOW REGISTER (local) (Device Default)
		{0x014,0x01},	// Output Mode SHADOW REGISTER (local)  (Twos Complement)
		{0x015,0x00},	// Output LVDS Control (global)  (Device Default)
		{0x016,0x00},	// Clock Phase Adjust SHADOW REGISTER (global)  (Device Default)
		{0x017,0x00},	// DCO Output Delay SHADOW REGISTER (global)  (Device Default)
		{0x018,0xC0},	// Input Span Select (global)  (Device Default)
		{0x030,0x00},	// Dither SHADOW REGISTER (local)  (Device Default)
		{0x045,0x00},	// Fast Detect (FD) Control  (Device Default)
		{0x047,0x08},	// FD Upper Threshold  (Device Default)
		{0x049,0x00},	// FD Lower Threshold [7:0]  (Device Default)
		{0x04A,0x02},	// FD Lower Threshold [14:8] (Device Default)
		{0x04B,0x00},	// FD Dwell Time [7:0]  (Device Default)
		{0x04C,0x08},	// FD Dwell Time [15:8]  (Device Default)
		{0x0FF,0x01},	// Transfer (global)  (Transfer SHADOW REGISTER Contents)
		{0x100,0x00},	// Sync Control (global)  (Device Default)
		{0x212,0x00},	// Dither Gain (global)  (Device Default)
		{0x22A,0x00},	// Input Frequency Settings (global)  (Device Default)
		{0x4FA,0x03},	// Calibration Power-down Configuration (global)  (Device Default)
		{0x4FB,0x08}	// Calibration Power-down Configuration (global)  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1_AMP_ENBL - REFER TO THE ADA4927 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{7,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{	// RX2_AMP_ENBL - REFER TO THE ADA4927 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// Note: Amplifier is only present on DC coupled units.
		// {Command/Status Port Number, Enable}
		{6,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
	},
	{  // PROG_SYNTH - Refer to product documentation for a detail description.
		// Note: Programmable synthesizer is a build option.
		0,	// Output Frequency
		{
		// Reserved
		{0x0,0x00},		// Reserved
		{0x1,0x00},		// Reserved
		{0x2,0x00},		// Reserved
		{0x3,0x00},		// Reserved
		{0x4,0x00},		// Reserved
		{0x5,0x00},		// Reserved
		{0x6,0x00},		// Reserved
		{0x7,0x00}		// Reserved
		}
	}
};

////////////////////////////////////////////////  Configure Model 376 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 376 device initialization.
s_M376Devices M376Default = {
	{	// RX1TO2_ADC - REFER TO THE ADC12D1600 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes all addresses in sequence.
		{
		// {4-bit Address, 16-bit Data}
		{0x0,0x2010},	// Configuration Register 1  (DDR 90 Phase, High Voltage, Two's Complement)
		{0x2,0x0000},	// I-channel Offset Adjust  (Device Default)
		{0x3,0x4000},	// I-channel Full-Scale Range Adjust  (Device Default)
		{0x4,0xDF4B},	// Calibration Adjust  (Device Default)
		{0x5,0x0000},	// Calibration Values  (Read Only - Data Not Used)
		{0x7,0x8140},	// DES Timing Adjust  (Device Default)
		{0xA,0x0000},	// Q-channel Offset Adjust  (Device Default)
		{0xB,0x4000},	// Q-channel Full-Scale Range Adjust  (Device Default)
		{0xC,0x0004},	// Aperture Delay Coarse Adjust  (Device Default)
		{0xD,0x0000},	// Aperture Delay Fine Adjust  (Device Default)
		{0xE,0x0003}	// AutoSync  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1TO2_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{4,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{3,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	}
};

////////////////////////////////////////////////  Configure Model 377 Devices  /////////////////////////////////////////////////

// Initialize a default structure for the Model 377 device initialization.
s_M377Devices M377Default = {
	{  // AD9512 - REFER TO THE AD9512 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x0000,0x10},	// Serial Control Port Configuration
		{0x0034,0x01},	// Delay Bypass 4  (Device Default)
		{0x0035,0x00},	// Delay Full-Scale 4  (Device Default)
		{0x0036,0x00},	// Delay Fine Adjust 4  (Device Default)
		{0x003D,0x08},	// LVPECL OUT0  (Device Default)
		{0x003E,0x08},	// LVPECL OUT1  (Device Default)
		{0x003F,0x08},	// LVPECL OUT2  (Device Default)
		{0x0040,0x01},	// LVDS_CMOS OUT3  (Power Down OUT3)
		{0x0041,0x02},	// LVDS_CMOS OUT4  (Device Default)
		{0x0045,0x05},	// Clocks Select, Power-Down Options (Select Internal Sample Clock Source)
		{0x004A,0x00},	// Divider 0  (Device Default)
		{0x004B,0x80},	// Divider 0  (Bypass DIV0)
		{0x004C,0x11},	// Divider 1  (Device Default)
		{0x004D,0x80},	// Divider 1  (Bypass DIV1)
		{0x004E,0x33},	// Divider 2  (Device Default)
		{0x004F,0x80},	// Divider 2  (Bypass DIV2)
		{0x0050,0x00},	// Divider 3  (Device Default)
		{0x0051,0x00},	// Divider 3  (Device Default)
		{0x0052,0x11},	// Divider 4  (Device Default)
		{0x0053,0x80},	// Divider 4  (Bypass DIV4)
		{0x0058,0x00},	// Function Pin and Sync  (Device Default)
		{0x005A,0x01}	// Update Registers  (Update Registers)
		}
	},
	{  // ADS42LB69 - REFER TO THE ADS42LB69 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x04,0x00},	// LVDS Configuration #1  (Device Default)
		{0x05,0x00},	// LVDS Configuration #2  (Device Default)
		{0x06,0x00},	// Clock Divider  (Device Default)
		{0x07,0x00},	// SYNC Delay  (Device Default)
		{0x08,0x08},	// Power and Data Format Configuration  (Disable CTRL Pins)
		{0x0B,0x00},	// Channel A Gain Setting and Bit Ordering  (Device Default)
		{0x0C,0x00},	// Channel B Gain Setting and Bit Ordering  (Device Default)
		{0x0D,0x00},	// Over-range Setting  (Device Default)
		{0x0F,0x00},	// Test Pattern Selection  (Device Default)
		{0x10,0x00},	// Custom Pattern #1 (15:8) (Device Default)
		{0x11,0x00},	// Custom Pattern #1 (7:0)  (Device Default)
		{0x12,0x00},	// Custom Pattern #2 (15:8)  (Device Default)
		{0x13,0x00},	// Custom Pattern #2 (7:0)  (Device Default)
		{0x14,0x00},	// Output Drive Strength  (Device Default)
		{0x15,0x01},	// Output Driver Format  (Set DDR LVDS Mode)
		{0x16,0x00},	// Output Driver Timing  (Device Default)
		{0x17,0x00},	// Channel A Output Clock Timing  (Device Default)
		{0x18,0x00},	// Channel B Output Clock Timing  (Device Default)
		{0x1F,0xFF},	// Fast Over-range Threshold  (Device Default)
		{0x20,0x01},	// CTLR Pin Mode Select  (OVR)
		{0x30,0x00}		// SYNC Enable  (Device Default)
		}
	},
	{  // ADS42LB69 - REFER TO THE ADS42LB69 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x04,0x00},	// LVDS Configuration #1  (Device Default)
		{0x05,0x00},	// LVDS Configuration #2  (Device Default)
		{0x06,0x00},	// Clock Divider  (Device Default)
		{0x07,0x00},	// SYNC Delay  (Device Default)
		{0x08,0x08},	// Power and Data Format Configuration  (Disable CTRL Pins)
		{0x0B,0x00},	// Channel A Gain Setting and Bit Ordering  (Device Default)
		{0x0C,0x00},	// Channel B Gain Setting and Bit Ordering  (Device Default)
		{0x0D,0x00},	// Over-range Setting  (Device Default)
		{0x0F,0x00},	// Test Pattern Selection  (Device Default)
		{0x10,0x00},	// Custom Pattern #1 (15:8) (Device Default)
		{0x11,0x00},	// Custom Pattern #1 (7:0)  (Device Default)
		{0x12,0x00},	// Custom Pattern #2 (15:8)  (Device Default)
		{0x13,0x00},	// Custom Pattern #2 (7:0)  (Device Default)
		{0x14,0x00},	// Output Drive Strength  (Device Default)
		{0x15,0x01},	// Output Driver Format  (Set DDR LVDS Mode)
		{0x16,0x00},	// Output Driver Timing  (Device Default)
		{0x17,0x00},	// Channel A Output Clock Timing  (Device Default)
		{0x18,0x00},	// Channel B Output Clock Timing  (Device Default)
		{0x1F,0xFF},	// Fast Over-range Threshold  (Device Default)
		{0x20,0x01},	// CTLR Pin Mode Select  (OVR)
		{0x30,0x00}		// SYNC Enable  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX3_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX4_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1TO2_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{7,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{6,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	},
	{	// RX3TO4_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{5,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{4,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	},
	{  // ADF4110 - Sample Clock Frequency (Fout) = 100,000*[(16*B) + A] where A < 16.
	   // Example (A=0, B=100):  Fout = 100,000*[(16*100) + 0] = 160 MHz
		0,	// A		A counter. - Range: 6 bits
		100	// B		B counter. - Range: 13 bits
	}
};

#ifdef __cplusplus
}
#endif
